@@ -1,5 +1,5 @@
 from .viewing_angle_sampler import ViewingAngleSampler
-from .lognormal_aux_sampler import LogNormalAuxSampler
+from .lognormal_aux_sampler import LogNormalAuxSampler, Log10NormalAuxSampler
 from .normal_aux_sampler import NormalAuxSampler
 from .trunc_normal_aux_sampler import TruncatedNormalAuxSampler
 
