@@ -1,13 +1,22 @@
 import abc
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Union
 
 import numpy as np
-from nptyping import NDArray
 
 from popsynth.selection_probability import SelectionProbabilty, UnitySelection
+from popsynth.utils.logging import setup_logger
 from popsynth.utils.meta import Parameter, ParameterMeta
 
-SamplerDict = Dict[str, Dict[str, NDArray[Any]]]
+#from numpy.typing import ArrayLike
+
+
+
+
+log = setup_logger(__name__)
+
+
+ArrayLike = List[float]
+SamplerDict = Dict[str, Dict[str, ArrayLike]]
 
 
 class AuxiliaryParameter(Parameter):
@@ -27,8 +36,8 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         self._name = name  # type: str
         self._obs_name = "%s_obs" % name  # type: str
 
-        self._obs_values = None  # type: NDArray[Any]
-        self._true_values = None  # type: NDArray[Any]
+        self._obs_values = None  # type: ArrayLike
+        self._true_values = None  # type: ArrayLike
         self._is_observed = observed  # type: bool
         self._secondary_samplers = {}  # type: SamplerDict
         self._is_secondary = False  # type: bool
@@ -38,7 +47,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         self._uses_distance = uses_distance  # type: bool
         self._uses_luminoity = uses_luminosity  # type: bool
 
-    def set_luminosity(self, luminosity: NDArray[np.float64]) -> None:
+    def set_luminosity(self, luminosity: ArrayLike) -> None:
         """FIXME! briefly describe function
 
         :param luminosity:
@@ -47,9 +56,9 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
         """
 
-        self._luminosity = luminosity  # type: NDArray[np.float64]
+        self._luminosity = luminosity  # type:ArrayLike
 
-    def set_distance(self, distance: NDArray[np.float64]) -> None:
+    def set_distance(self, distance: ArrayLike) -> None:
         """FIXME! briefly describe function
 
         :param distance:
@@ -58,7 +67,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
         """
 
-        self._distance = distance  # type: NDArray[np.float64]
+        self._distance = distance  # type:ArrayLike
 
     def set_selection_probability(self, selector: SelectionProbabilty) -> None:
 
@@ -75,10 +84,6 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
         self._selector.draw(len(self._obs_values))
 
-        # self._selection = np.ones_like(
-        #     self._obs_values, dtype=bool
-        # )  # type: NDArray[np.bool_]
-
     def set_secondary_sampler(self, sampler) -> None:
         """
         Allows the setting of a secondary sampler from which to derive values
@@ -94,7 +99,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         self._secondary_samplers[sampler.name] = sampler
         self._has_secondary = True  # type: bool
 
-    def draw(self, size: int = 1, verbose: bool = True):
+    def draw(self, size: int = 1):
         """
         Draw the primary and secondary samplers. This is the main call.
 
@@ -102,12 +107,13 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         """
         # do not resample!
         if not self._is_sampled:
-            if verbose:
-                print("Sampling: %s" % self.name)
+
+            log.info("Sampling: %s" % self.name)
 
             if self._has_secondary:
-                if verbose:
-                    print("%s is sampling its secondary quantities" % self.name)
+
+                log.info("%s is sampling its secondary quantities" %
+                         self.name)
 
             if self._uses_distance:
                 self._selector.set_distance(self._distance)
@@ -123,7 +129,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
                 # quantities to derive a luminosity
                 # as it should be the last thing dervied
 
-                v.draw(size=size, verbose=verbose)
+                v.draw(size=size)
 
             # Now, it is assumed that if this sampler depends on the previous samplers,
             # then those properties have been drawn
@@ -136,19 +142,17 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
             else:
 
-                self._obs_values = (
-                    self._true_values
-                )  # type: NDArray[(size,),np.float64]
+                self._obs_values = (self._true_values)  # type: ArrayLike
 
             self._selector.set_observed_value(self._obs_values)
 
             # check to make sure we sampled!
-            assert (
-                self.true_values is not None and len(self.true_values) == size
-            ), f"{self.name} likely has a bad true_sampler function"
-            assert (
-                self.obs_values is not None and len(self.obs_values) == size
-            ), f"{self.name} likely has a observation_sampler function"
+            assert (self.true_values is not None
+                    and len(self.true_values) == size
+                    ), f"{self.name} likely has a bad true_sampler function"
+            assert (self.obs_values is not None
+                    and len(self.obs_values) == size
+                    ), f"{self.name} likely has a observation_sampler function"
 
             # now apply the selection to yourself
             # if there is nothing coded, it will be
@@ -164,7 +168,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
     def get_secondary_properties(
         self,
-        recursive_secondaries: Union[Dict[str, NDArray[Any]], None] = None,
+        recursive_secondaries: Union[Dict[str, ArrayLike], None] = None,
         graph=None,
         primary=None,
         spatial_distribution=None,
@@ -201,8 +205,8 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
                         self._graph.add_edge(spatial_distribution.name, k)
 
                 recursive_secondaries = v.get_secondary_properties(
-                    recursive_secondaries, graph, k, spatial_distribution
-                )  # type: SamplerDict
+                    recursive_secondaries, graph, k,
+                    spatial_distribution)  # type: SamplerDict
 
         # add our own on
         recursive_secondaries[self._name] = {
@@ -245,7 +249,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         return self._obs_name
 
     @property
-    def true_values(self) -> NDArray[np.float64]:
+    def true_values(self) -> np.ndarray:
         """
         The true values
 
@@ -257,7 +261,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         return self._true_values
 
     @property
-    def obs_values(self) -> NDArray[np.float64]:
+    def obs_values(self) -> np.ndarray:
         """
         The observed values
         :returns:
@@ -268,7 +272,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         return self._obs_values
 
     @property
-    def selection(self) -> NDArray[np.bool_]:
+    def selection(self) -> np.ndarray:
         """
         The selection function
 
@@ -292,7 +296,7 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
         return self._uses_distance
 
     @property
-    def uses_luminosity(self) -> NDArray[np.float64]:
+    def uses_luminosity(self) -> np.ndarray:
         return self._luminosity
 
     @abc.abstractmethod
@@ -300,15 +304,16 @@ class AuxiliarySampler(object, metaclass=ParameterMeta):
 
         pass
 
-    def observation_sampler(self, size: int = 1) -> NDArray[np.float64]:
+    def observation_sampler(self, size: int = 1) -> np.ndarray:
 
         return self._true_values
 
 
 class NonObservedAuxSampler(AuxiliarySampler):
-    def __init__(
-        self, name: str, uses_distance: bool = False, uses_luminosity: bool = False
-    ):
+    def __init__(self,
+                 name: str,
+                 uses_distance: bool = False,
+                 uses_luminosity: bool = False):
 
         super(NonObservedAuxSampler, self).__init__(
             name=name,
@@ -330,9 +335,9 @@ class DerivedLumAuxSampler(AuxiliarySampler):
 
         """
 
-        super(DerivedLumAuxSampler, self).__init__(
-            name, observed=False, uses_distance=uses_distance
-        )
+        super(DerivedLumAuxSampler, self).__init__(name,
+                                                   observed=False,
+                                                   uses_distance=uses_distance)
 
     @abc.abstractmethod
     def compute_luminosity(self):
