@@ -1,13 +1,22 @@
 import abc
-from typing import Union, Dict
-from nptyping import NDArray
-import numpy as np
-from tqdm.autonotebook import tqdm as progress_bar
+from typing import Dict, List, Union
 
+import numpy as np
+
+from popsynth.utils.configuration import popsynth_config
+from popsynth.utils.logging import setup_logger
 from popsynth.utils.meta import Parameter, ParameterMeta
+from popsynth.utils.progress_bar import progress_bar
 from popsynth.utils.rejection_sample import rejection_sample
 from popsynth.utils.spherical_geometry import sample_theta_phi
 
+#from numpy.typing import ArrayLike
+
+ArrayLike = List[float]
+
+
+log = setup_logger(__name__)
+
 
 class DistributionParameter(Parameter):
     pass
@@ -68,7 +77,9 @@ class SpatialDistribution(Distribution):
         self._theta = None
         self._phi = None
 
-        super(SpatialDistribution, self).__init__(name=name, seed=seed, form=form)
+        super(SpatialDistribution, self).__init__(name=name,
+                                                  seed=seed,
+                                                  form=form)
 
     @abc.abstractmethod
     def differential_volume(self, distance):
@@ -105,43 +116,49 @@ class SpatialDistribution(Distribution):
         pass
 
     @property
-    def theta(self) -> NDArray[np.float64]:
+    def theta(self) -> np.ndarray:
         return self._theta
 
     @property
-    def phi(self) -> NDArray[np.float64]:
+    def phi(self) -> np.ndarray:
         return self._phi
 
     @property
-    def distances(self) -> NDArray[np.float64]:
+    def dec(self) -> np.ndarray:
+        return 90 - np.rad2deg(self._theta)
+
+    @property
+    def ra(self) -> np.ndarray:
+        return np.rad2deg(self._phi)
+
+    @property
+    def distances(self) -> np.ndarray:
         return self._distances
 
     def draw_sky_positions(self, size: int) -> None:
 
         self._theta, self._phi = sample_theta_phi(size)
 
-    def draw_distance(self, size: int, verbose: bool) -> None:
+    def draw_distance(self, size: int) -> None:
         """
         Draw the distances from the specified dN/dr model
         """
 
         # create a callback for the sampler
-        dNdr = (
-            lambda r: self.dNdV(r)
-            * self.differential_volume(r)
-            / self.time_adjustment(r)
-        )
+        dNdr = (lambda r: self.dNdV(r) * self.differential_volume(r) / self.
+                time_adjustment(r))
 
         # find the maximum point
-        tmp = np.linspace(
-            0.0, self.r_max, 500, dtype=np.float64
-        )  # type: NDArray[(500,), np.float64]
+        tmp = np.linspace(0.0, self.r_max, 500,
+                          dtype=np.float64)  # type: ArrayLike
         ymax = np.max(dNdr(tmp))  # type: float
 
         # rejection sampling the distribution
         r_out = []
 
-        if verbose:
+        # slow
+
+        if popsynth_config["show_progress"]:
             for i in progress_bar(range(size), desc="Drawing distances"):
                 flag = True
                 while flag:
@@ -152,7 +169,8 @@ class SpatialDistribution(Distribution):
 
                     # get an rvs from 0 to the maximum distance
 
-                    r = np.random.uniform(low=0, high=self.r_max)  # type: float
+                    r = np.random.uniform(low=0,
+                                          high=self.r_max)  # type: float
 
                     # compare them
 
@@ -161,11 +179,10 @@ class SpatialDistribution(Distribution):
                         flag = False
         else:
 
-            r_out = rejection_sample(
-                size, ymax, self.r_max, dNdr
-            )  # type: NDArray[(size,), np.float64]
+            r_out = rejection_sample(size, ymax, self.r_max,
+                                     dNdr)  # type: ArrayLike
 
-        self._distances = np.array(r_out)  # type: NDArray[(size,), np.float64]
+        self._distances = np.array(r_out)  # type: ArrayLike
 
 
 class LuminosityDistribution(Distribution):
