@@ -1,5 +1,5 @@
 import abc
-from typing import Union
+from typing import Optional, Union
 
 import networkx as nx
 import numpy as np
@@ -8,10 +8,8 @@ import scipy.integrate as integrate
 import scipy.special as sf
 import scipy.stats as stats
 from IPython.display import Markdown, Math, display
-from nptyping import NDArray
+# from numpy.typing import np.ndarray
 from numba import float64, jit, njit, prange
-# from popsynth.utils.progress_bar import progress_bar
-from tqdm.autonotebook import tqdm as progress_bar
 
 from popsynth.auxiliary_sampler import AuxiliarySampler, DerivedLumAuxSampler
 from popsynth.distribution import LuminosityDistribution, SpatialDistribution
@@ -20,6 +18,11 @@ from popsynth.selection_probability import (BernoulliSelection,
                                             HardFluxSelection,
                                             SelectionProbabilty,
                                             SoftFluxSelection, UnitySelection)
+from popsynth.utils.logging import setup_logger
+# from popsynth.utils.progress_bar import progress_bar
+from popsynth.utils.progress_bar import progress_bar
+
+log = setup_logger(__name__)
 
 
 class PopulationSynth(object, metaclass=abc.ABCMeta):
@@ -28,7 +31,7 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         spatial_distribution: SpatialDistribution,
         luminosity_distribution: Union[LuminosityDistribution, None] = None,
         seed: int = 1234,
-        verbose: bool = True,
+
     ):
         """
         Basic and generic population synth. One specifies the spatial and luminosity distribution OR
@@ -53,8 +56,6 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         self._graph = nx.DiGraph()  # type: nx.Digraph
 
-        self._verbose = verbose  # type: bool
-
         self._name = "%s" % spatial_distribution.name  # type: str
         if luminosity_distribution is not None:
             self._name = "%s_%s" % (self._name, luminosity_distribution.name)
@@ -63,8 +64,8 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
             ), "the luminosity_distribution is the wrong type"
 
         assert isinstance(
-            spatial_distribution, SpatialDistribution
-        ), "the spatial_distribution is the wrong type"
+            spatial_distribution,
+            SpatialDistribution), "the spatial_distribution is the wrong type"
 
         self._spatial_distribution = spatial_distribution  # type: SpatialDistribution
         self._luminosity_distribution = (
@@ -73,16 +74,16 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         self._has_derived_luminosity = False  # type: bool
         self._derived_luminosity_sampler = (
-            None
-        )  # type: Union[DerivedLumAuxSampler, None]
+            None)  # type: Union[DerivedLumAuxSampler, None]
 
         # set the selections be fully seen unless it is set by the user
-        self._distance_selector = UnitySelection()  # type: SelectionProbabilty
-        self._flux_selector = UnitySelection()  # type: SelectionProbabilty
+        self._distance_selector: SelectionProbabilty = UnitySelection()
+        self._flux_selector: SelectionProbabilty = UnitySelection()
 
         # check to see if the selectors are set
-        self._distance_selector_set = False  # type: bool
-        self._flux_selector_set = False  # type: bool
+        self._distance_selector_set: bool = False
+        self._flux_selector_set: bool = False
+        self._spatial_selector: Union[SelectionProbabilty, None] = None
 
         self._params = {}  # type: dict
 
@@ -128,9 +129,9 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         self._model_spaces[name] = space
 
-    def add_observed_quantity(
-        self, auxiliary_sampler: Union[DerivedLumAuxSampler, AuxiliarySampler]
-    ):
+    def add_observed_quantity(self,
+                              auxiliary_sampler: Union[DerivedLumAuxSampler,
+                                                       AuxiliarySampler]):
         """FIXME! briefly describe function
 
         :param auxiliary_sampler:
@@ -140,11 +141,9 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         """
 
         if isinstance(auxiliary_sampler, DerivedLumAuxSampler):
-            if self._verbose:
-                print(
-                    "registering derived luminosity sampler: %s"
-                    % auxiliary_sampler.name
-                )
+
+            log.info("registering derived luminosity sampler: %s" %
+                     auxiliary_sampler.name)
 
             self._has_derived_luminosity = True
             self._derived_luminosity_sampler = auxiliary_sampler
@@ -154,13 +153,14 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
             assert (
                 not auxiliary_sampler.is_secondary
             ), f"{auxiliary_sampler.name} is already set as a secondary sampler!"
-            assert (
-                auxiliary_sampler.name not in self._auxiliary_observations
-            ), f"{auxiliary_sampler.name} is already registered!"
-            if self._verbose:
-                print("registering auxilary sampler: %s" % auxiliary_sampler.name)
+            assert (auxiliary_sampler.name not in self._auxiliary_observations
+                    ), f"{auxiliary_sampler.name} is already registered!"
 
-            self._auxiliary_observations[auxiliary_sampler.name] = auxiliary_sampler
+            log.info("registering auxilary sampler: %s" %
+                     auxiliary_sampler.name)
+
+            self._auxiliary_observations[
+                auxiliary_sampler.name] = auxiliary_sampler
 
     def set_distance_selection(self, selector: SelectionProbabilty) -> None:
         """
@@ -183,7 +183,18 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         self._flux_selector_set = True
 
-    def _prob_det(self, x, boundary, strength) -> NDArray[np.float64]:
+    def add_spatial_selector(self,
+                             spatial_selector: SelectionProbabilty) -> None:
+        """
+        Add a spatial selector into the mix
+        """
+
+        assert isinstance(spatial_selector, SelectionProbabilty)
+
+        self._spatial_selector: SelectionProbabilty = spatial_selector
+
+    def _prob_det(self, x: np.ndarray, boundary: float,
+                  strength: float) -> np.ndarray:
         """
         Soft detection threshold
 
@@ -198,7 +209,7 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
     def name(self) -> str:
         return self._name
 
-    def draw_log10_fobs(self, f, f_sigma, size=1) -> NDArray[np.float64]:
+    def draw_log10_fobs(self, f, f_sigma, size=1) -> np.ndarray:
         """
         draw the log10 of the the fluxes
         """
@@ -206,11 +217,12 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         log10_f = np.log10(f)
 
         # sample from the log distribution to keep positive fluxes
-        log10_fobs = log10_f + np.random.normal(loc=0, scale=f_sigma, size=size)
+        log10_fobs = log10_f + np.random.normal(
+            loc=0, scale=f_sigma, size=size)
 
         return log10_fobs
 
-    def draw_log_fobs(self, f, f_sigma, size=1) -> NDArray[np.float64]:
+    def draw_log_fobs(self, f, f_sigma, size=1) -> np.ndarray:
         """
         draw the log10 of the the fluxes
         """
@@ -222,18 +234,15 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         return log_fobs
 
-
-    
     def draw_survey(
         self,
         boundary: float,
         flux_sigma: float = 1.0,
         strength: float = 10.0,
         hard_cut: bool = False,
-        distance_probability: Union[float, None] = None,
-        no_selection: bool = False,
-        verbose: bool = True,
-        log10_flux_draw: bool=True,
+        distance_probability: Optional[float] = None,
+            no_selection: bool = False,
+        log10_flux_draw: bool = True,
     ) -> Population:
         """
         Draw the total survey and return a Population object
@@ -250,44 +259,37 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         truth = dict()  # type: dict
 
         # store the spatial distribution truths
-        truth[self._spatial_distribution.name] = self._spatial_distribution.truth
+        truth[
+            self._spatial_distribution.name] = self._spatial_distribution.truth
 
         # set the random seed
 
-        #        pbar = progress_bar(total=5, desc='Integrating volume')
         np.random.seed(self._seed)
 
         # create a callback of the integrand
-        dNdr = (
-            lambda r: self._spatial_distribution.dNdV(r)
-            * self._spatial_distribution.differential_volume(r)
-            / self._spatial_distribution.time_adjustment(r)
-        )
+        dNdr = (lambda r: self._spatial_distribution.dNdV(
+            r) * self._spatial_distribution.differential_volume(r) / self.
+            _spatial_distribution.time_adjustment(r))
 
         # integrate the population to determine the true number of
         # objects
-        N = integrate.quad(dNdr, 0.0, self._spatial_distribution.r_max)[
-            0
-        ]  # type: float
+        N = integrate.quad(dNdr, 0.0,
+                           self._spatial_distribution.r_max)[0]  # type: float
 
-        if verbose:
-            print("The volume integral is %f" % N)
+        log.info("The volume integral is %f" % N)
 
         # this should be poisson distributed
         n = np.random.poisson(N)  # type: np.int64
 
-        self._spatial_distribution.draw_distance(size=n, verbose=verbose)
+        self._spatial_distribution.draw_distance(size=n)
 
         # now draw the sky positions
 
         self._spatial_distribution.draw_sky_positions(size=n)
 
-        distances = (
-            self._spatial_distribution.distances
-        )  # type: NDArray[(n,), np.float64]
+        distances = self._spatial_distribution.distances  # type: np.ndarray
 
-        if verbose:
-            print("Expecting %d total objects" % n)
+        log.info("Expecting %d total objects" % n)
 
         # first check if the auxilliary samplers
         # compute the luminosities
@@ -297,13 +299,13 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         # setup the global selection
 
         global_selection = UnitySelection()  # type: SelectionProbabilty
-        global_selection.draw(n, verbose=False)
+        global_selection.draw(n)
 
         # now we set up the selection that _may_ come
         # from the auxilliary samplers
 
         auxiliary_selection = UnitySelection()  # type: SelectionProbabilty
-        auxiliary_selection.draw(n, verbose=False)
+        auxiliary_selection.draw(n)
 
         auxiliary_quantities = {}  # type: dict
 
@@ -323,18 +325,14 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
             # sample the true and obs
             # values which are held internally
 
-            self._derived_luminosity_sampler.draw(size=n, verbose=verbose)
+            self._derived_luminosity_sampler.draw(size=n)
 
             # check to make sure we sampled!
-            assert (
-                self._derived_luminosity_sampler.true_values is not None
-                and len(self._derived_luminosity_sampler.true_values) == n
-            )
+            assert (self._derived_luminosity_sampler.true_values is not None
+                    and len(self._derived_luminosity_sampler.true_values) == n)
 
-            assert (
-                self._derived_luminosity_sampler.obs_values is not None
-                and len(self._derived_luminosity_sampler.obs_values) == n
-            )
+            assert (self._derived_luminosity_sampler.obs_values is not None
+                    and len(self._derived_luminosity_sampler.obs_values) == n)
 
             # append these values to a dict
             auxiliary_quantities[self._derived_luminosity_sampler.name] = {
@@ -342,21 +340,22 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
                 "obs_values": self._derived_luminosity_sampler.obs_values,
                 "selection": self._derived_luminosity_sampler.selector,
             }
-            if verbose:
-                print("Getting luminosity from derived sampler")
+
+            log.info("Getting luminosity from derived sampler")
+
             luminosities = (
                 self._derived_luminosity_sampler.compute_luminosity()
-            )  # type: NDArray[(n,), np.float64]
+            )  # type: np.ndarray
 
             # collect anything that was sampled here
 
             # store the truth from the derived lum sampler
 
-            truth[
-                self._derived_luminosity_sampler.name
-            ] = self._derived_luminosity_sampler.truth
+            truth[self._derived_luminosity_sampler.
+                  name] = self._derived_luminosity_sampler.truth
 
-            for k2, v2 in self._derived_luminosity_sampler.secondary_samplers.items():
+            for k2, v2 in self._derived_luminosity_sampler.secondary_samplers.items(
+            ):
 
                 # first we tell the sampler to go and retrieve all of
                 # its own secondaries
@@ -374,24 +373,18 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
                 truth[v2.name] = v2.truth
 
-            # pbar.update()
-
         else:
-            # pbar.update()
-            # draw all the values
+
             luminosities = self.luminosity_distribution.draw_luminosity(
-                size=n
-            )  # type: NDArray[(n,), np.float64]
+                size=n)  # type: np.ndarray
 
             # store the truths from the luminosity distribution
-            truth[
-                self.luminosity_distribution.name
-            ] = self.luminosity_distribution.truth
+            truth[self.luminosity_distribution.
+                  name] = self.luminosity_distribution.truth
 
         # transform the fluxes
         fluxes = self._spatial_distribution.transform(
-            luminosities, distances
-        )  # type: NDArray[(n,), np.float64]
+            luminosities, distances)  # type: np.ndarray
 
         # now sample any auxilary quantities
         # if needed
@@ -414,7 +407,7 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
             # values which are held internally
             # this will also invoke secondary samplers
 
-            v.draw(size=n, verbose=verbose)
+            v.draw(size=n)
 
             # store the auxilliary truths
             truth[v.name] = v.truth
@@ -455,23 +448,17 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
         if log10_flux_draw:
 
-            log10_fluxes_obs = self.draw_log10_fobs(
-                fluxes, flux_sigma, size=n
-            )  # type: NDArray[(n,), np.float64]
+            log10_fluxes_obs = self.draw_log10_fobs(fluxes, flux_sigma,
+                                                    size=n)  # type: np.ndarray
             flux_obs = np.power(10, log10_fluxes_obs)
 
         else:
 
-            log10_fluxes_obs = self.draw_log_fobs(
-                fluxes, flux_sigma, size=n
-            )  # type: NDArray[(n,), np.float64]
+            log10_fluxes_obs = self.draw_log_fobs(fluxes, flux_sigma,
+                                                  size=n)  # type: np.ndarray
 
             flux_obs = np.exp(log10_fluxes_obs)
 
-
-
-
-            
         assert np.alltrue(np.isfinite(log10_fluxes_obs))
 
         # now select them
@@ -488,15 +475,11 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
                     self._flux_selector = SoftFluxSelection(boundary, strength)
 
-                    if verbose:
-
-                        print("Applying soft boundary")
+                    log.info("Applying soft boundary")
 
                 else:
 
-                    if verbose:
-
-                        print("Applying hard boundary")
+                    log.info("Applying hard boundary")
 
                     self._flux_selector = HardFluxSelection(boundary)
 
@@ -504,16 +487,28 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
             # properties to let us know what type of selection
             # was made so we can record it
 
-            if self._flux_selector.hard_cut:
+            if isinstance(self._flux_selector,
+                          HardFluxSelection) or isinstance(
+                              self._flux_selector, SoftFluxSelection):
 
-                strength = 1.0
+                if self._flux_selector.hard_cut:
+
+                    strength = 1.0
+
+                else:
+
+                    strength = self._flux_selector.strength
+
+                boundary = self._flux_selector.boundary
+                hard_cut = self._flux_selector.hard_cut
 
             else:
 
-                strength = self._flux_selector.strength
+                # These are just dummies for other types of flux selection
 
-            boundary = self._flux_selector.boundary
-            hard_cut = self._flux_selector.hard_cut
+                strength = 1
+                boundary = 1e-99
+                hard_cut = True
 
         else:
 
@@ -536,22 +531,13 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
             auxiliary_selection += v["selection"]
 
-            if verbose:
+            log.info("Applying selection from %s which selected %d of %d objects"
+                     % (k, v["selection"].n_selected,
+                         v["selection"].n_objects))
 
-                if v["selection"].n_non_selected > 0:
-
-                    print(
-                        "Applying selection from %s which selected %d of %d objects"
-                        % (k, v["selection"].n_selected, v["selection"].n_objects)
-                    )
-
-        if verbose:
-
-            if auxiliary_selection.n_non_selected > 0:
-                print(
-                    "Before auxiliary selection there were %d objects selected"
-                    % self._flux_selector.n_selected
-                )
+            log.info(
+                "Before auxiliary selection there were %d objects selected"
+                % self._flux_selector.n_selected)
 
         # now we can add the values onto the global
         # selection
@@ -563,51 +549,51 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
             global_selection += self._flux_selector
 
-        # # if we do not want to add a selection effect
-        # if no_selection:
-        #     if self._verbose:
-        #         print("No Selection! Added back all objects")
+            # now scan the spatial selector
 
-        #     selection = np.ones_like(
-        #         selection, dtype=bool
-        #     )  # type: NDArray[(n,), np.bool_]
+            if (self._spatial_selector is not None) and (not no_selection):
+
+                self._spatial_selector.set_spatial_distribution(
+                    self._spatial_distribution)
+
+                self._spatial_selector.draw(n)
+
+                log.info(
+                    f"Appling selection from {self._spatial_selector.name} which selected {self._spatial_selector.n_selected} of {self._spatial_selector.n_objects}")
+
+                global_selection += self._spatial_selector
 
-        # pbar.update()
         if global_selection.n_selected == n:
 
-            if verbose:
-                print("NO HIDDEN OBJECTS")
+            log.warning("NO HIDDEN OBJECTS")
 
         if not self._distance_selector_set:
 
-            if (distance_probability is not None) or (distance_probability == 1.0):
+            if (distance_probability is not None) or (distance_probability
+                                                      == 1.0):
 
-                self._distance_selector = BernoulliSelection(distance_probability)
+                self._distance_selector = BernoulliSelection(
+                    distance_probability)
 
-        self._distance_selector.draw(size=global_selection.n_selected, verbose=verbose)
+        self._distance_selector.draw(size=global_selection.n_selected)
 
         known_distances = distances[global_selection.selection][
-            self._distance_selector.selection
-        ]
+            self._distance_selector.selection]
         known_distance_idx = self._distance_selector.selection_index
         unknown_distance_idx = self._distance_selector.non_selection_index
 
-        if verbose:
-            print("Detected %d distances" % len(known_distances))
+        log.info("Detected %d distances" % len(known_distances))
 
-        if verbose:
-            try:
+        try:
 
-                print(
-                    "Deteced %d objects or to a distance of %.2f"
-                    % (global_selection.n_selected, max(known_distances))
-                )
+            log.info("Deteced %d objects our to a distance of %.2f" %
+                     (global_selection.n_selected, max(known_distances)))
 
-            except:
-                print("No Objects detected")
-        # return a Population object
+        except:
 
-        ## just to make sure we do not do anything nutty
+            log.warning("No Objects detected")
+
+        # just to make sure we do not do anything nutty
         lf_params = None
         lf_form = None
         if self._luminosity_distribution is not None:
@@ -618,8 +604,6 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
         if distance_probability is None:
             distance_probability = 1.0
 
-
-             
         return Population(
             luminosities=luminosities,
             distances=distances,
@@ -708,7 +692,8 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
 
             self._graph.add_node(self._derived_luminosity_sampler.name)
 
-            self._graph.add_edge(self._derived_luminosity_sampler.name, "obs_flux")
+            self._graph.add_edge(self._derived_luminosity_sampler.name,
+                                 "obs_flux")
 
             if self._derived_luminosity_sampler.uses_distance:
 
@@ -717,7 +702,8 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
                     self._derived_luminosity_sampler.name,
                 )
 
-            for k2, v2 in self._derived_luminosity_sampler.secondary_samplers.items():
+            for k2, v2 in self._derived_luminosity_sampler.secondary_samplers.items(
+            ):
 
                 self._graph.add_node(k2)
                 self._graph.add_edge(k2, self._derived_luminosity_sampler.name)
@@ -731,7 +717,8 @@ class PopulationSynth(object, metaclass=abc.ABCMeta):
                 )
 
         else:
-            self._graph.add_edge(self._luminosity_distribution.name, "obs_flux")
+            self._graph.add_edge(self._luminosity_distribution.name,
+                                 "obs_flux")
         # now do the same fro everything else
 
         for k, v in self._auxiliary_observations.items():
